Authors
=======

Thermopy is written and maintained by Adel Qalieh and various contributors:

- Guillem Borrell i Nogueras <guillem@torroja.dmt.upm.es>
- Adel Qalieh <adelq@sas.upenn.edu>
- Zack Gainsforth <zsg@gainsforth.com>

The development of this package was originally written by Guillem Borrel i
Nogueras and funded by Vulcano Sadeca S.A.
